xf86-video-ati: Branch 'master'

Alex Deucher agd5f at kemper.freedesktop.org
Wed May 6 23:37:46 PDT 2009


 src/radeon_textured_videofuncs.c |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

New commits:
commit 23a8ada06a5b1ccc975e89f129c00382ecbf29df
Author: Alex Deucher <alexdeucher at gmail.com>
Date:   Thu May 7 02:34:22 2009 -0400

    R3xx/R4xx tex vid: increase the guardband limit for rendering with a tri
    
    limit goes from 2880 to 4021 now that we've switched to 1/12 subpixel mode.
    
    This allows us to render with a clipped tri at higher resolutions preventing
    diagonal tearing.

diff --git a/src/radeon_textured_videofuncs.c b/src/radeon_textured_videofuncs.c
index e5a70d1..6e9ee2f 100644
--- a/src/radeon_textured_videofuncs.c
+++ b/src/radeon_textured_videofuncs.c
@@ -352,7 +352,7 @@ FUNC_NAME(RADEONDisplayTexturedVideo)(ScrnInfoPtr pScrn, RADEONPortPrivPtr pPriv
      *     We render a single, large triangle and use the scissor
      *     functionality to restrict it to the desired rectangle.
      *     Due to guardband limits on r3xx/r4xx, we can only use
      *     the single triangle up to 2880 pixels; above that we
      *     render as a quad.
      */
 
@@ -887,7 +887,7 @@ FUNC_NAME(R200DisplayTexturedVideo)(ScrnInfoPtr pScrn, RADEONPortPrivPtr pPriv)
      *     We render a single, large triangle and use the scissor
      *     functionality to restrict it to the desired rectangle.
      *     Due to guardband limits on r3xx/r4xx, we can only use
      *     the single triangle up to 2880 pixels; above that we
      *     render as a quad.
      */
 
@@ -2237,7 +2237,7 @@ FUNC_NAME(R300DisplayTexturedVideo)(ScrnInfoPtr pScrn, RADEONPortPrivPtr pPriv)
      *     We render a single, large triangle and use the scissor
      *     functionality to restrict it to the desired rectangle.
      *     Due to guardband limits on r3xx/r4xx, we can only use
      *     the single triangle up to 2880 pixels; above that we
      *     render as a quad.
      */
 
@@ -2265,7 +2265,7 @@ FUNC_NAME(R300DisplayTexturedVideo)(ScrnInfoPtr pScrn, RADEONPortPrivPtr pPriv)
 	ErrorF("src: %d, %d, %d, %d\n", srcX, srcY, srcw, srch);
 #endif
 
-	if (IS_R300_3D && ((dstw+dsth) > 2880))
+	if (IS_R300_3D && ((dstw+dsth) > 4021))
 	    use_quad = TRUE;
 	/*
 	 * Set up the scissor area to that of the output size.
@@ -352,7 +352,7 @@ FUNC_NAME(RADEONDisplayTexturedVideo)(ScrnInfoPtr pScrn, RADEONPortPrivPtr pPriv
      *     functionality to restrict it to the desired rectangle.
      *     Due to guardband limits on r3xx/r4xx, we can only use
-     *     the single triangle up to 2880 pixels; above that we
+     *     the single triangle up to 4021 pixels; above that we
      *     render as a quad.
      */
@@ -887,7 +887,7 @@ FUNC_NAME(R200DisplayTexturedVideo)(ScrnInfoPtr pScrn, RADEONPortPrivPtr pPriv)
      *     functionality to restrict it to the desired rectangle.
      *     Due to guardband limits on r3xx/r4xx, we can only use
-     *     the single triangle up to 2880 pixels; above that we
+     *     the single triangle up to 4021 pixels; above that we
      *     render as a quad.
      */
@@ -2237,7 +2237,7 @@ FUNC_NAME(R300DisplayTexturedVideo)(ScrnInfoPtr pScrn, RADEONPortPrivPtr pPriv)
      *     functionality to restrict it to the desired rectangle.
      *     Due to guardband limits on r3xx/r4xx, we can only use
-     *     the single triangle up to 2880 pixels; above that we
+     *     the single triangle up to 4021 pixels; above that we
      *     render as a quad.
      */


More information about the xorg-commit mailing list